#include <QTabWidget>
#include <QLabel>
#include <QVBoxLayout>
#include <QMouseEvent>
#include "widget.h"
#include "mylabel.h"

Widget::Widget(QWidget *parent) :
    QWidget(parent), m_tabWidget(0), m_currentWidget(0)
  , m_label_firstTab(0), m_label_secondTab(0)
{
    m_label_firstTab = new MyLabel ("Label 1: click me!");
    m_label_secondTab = new MyLabel ("Label 2: click me!");
    m_tabWidget = new QTabWidget;
    m_tabWidget->addTab(m_label_firstTab, "Tab 1");
    m_tabWidget->addTab(m_label_secondTab, "Tab 2");

    connect(m_label_firstTab, SIGNAL(mouseReleasedForTabWidget()), this, SLOT(addNewTab()));
    connect(m_label_secondTab, SIGNAL(mouseReleasedForTabWidget()), this, SLOT(addNewTab()));

    QVBoxLayout *layout = new QVBoxLayout;
    layout->addWidget(m_tabWidget);
    setLayout(layout);
}

void Widget::mousePressEvent ( QMouseEvent * event )
{
    // left mouse button pressed --> reparent the current widget
    if (event->button() == Qt::LeftButton) {
        m_currentWidget = m_tabWidget->currentWidget();

        if (m_currentWidget) {
            m_currentWidget->setParent(0);
            m_currentWidget->move(event->globalPos());
            m_currentWidget->show();
        }
    }
    else
        QWidget::mousePressEvent(event);
}

void Widget::addNewTab()
{
    QPoint cursor = m_tabWidget->mapFromGlobal(QCursor::pos());

    if (m_tabWidget->rect().contains(cursor) ) {
        MyLabel *label = qobject_cast<MyLabel *>(sender());
        m_tabWidget->addTab(label, "New tab");
    }
}
